# @summary A short summary of the purpose of this class
#
# A description of what this class does
#
# @example
#   include masterless::puppet::config
class masterless::puppet::config (
  Enum['present', 'absent'] $ensure = 'present',
  String[1] $user = $masterless::user,
  String[1] $home = $masterless::home,
  String[1] $group = $masterless::group,
  String[1] $plist = $masterless::plist,
  Integer $start_interval = 3600,
) {

  $data = {
    'Label'                => "com.github.puppet-masterless-${user}",
    'EnvironmentVariables' => {
      'PATH' => '/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin',
      'LANG' => 'en_US.UTF-8'
    },
    'Program'              => "${home}/.puppet-masterless/run.sh",
    'StartInterval'        => $start_interval,
    'RunAtLoad'            => true,
  }

  file { $plist:
    ensure  => $ensure,
    content => hash2plist($data),
  }

  file { "${home}/.puppet-masterless":
    ensure => directory,
    owner  => $user,
    group  => $group,
  }

  file { "${home}/.puppet-masterless/run.sh":
    ensure  => $ensure,
    owner   => $user,
    group   => $group,
    mode    => '0755',
    content => template('masterless/run.sh.erb'),
    # source  => 'puppet:///modules/masterless/run.sh', # Change this to a template
    notify  => Exec['reload_job'],
  }

  $userdirs = [
    "${facts['puppet_user_home']}/.puppetlabs/",
    "${facts['puppet_user_home']}/.puppetlabs/etc/",
    "${facts['puppet_user_home']}/.puppetlabs/etc/code/",
    "${facts['puppet_user_home']}/.puppetlabs/etc/code/environments",
  ]

  if $facts['puppet_user'] != 'root' {
    file { $userdirs:
      ensure => directory,
      owner  => $user,
      group  => $group,
    }
  }

}

